@@ -1,4 +1,5 @@
 mod use_async;
+mod use_before_unload;
 mod use_counter;
 mod use_effect_once;
 mod use_event;
@@ -21,8 +22,10 @@ mod use_title;
 mod use_toggle;
 mod use_unmount;
 mod use_update;
+mod use_window_size;
 
 pub use use_async::*;
+pub use use_before_unload::*;
 pub use use_counter::*;
 pub use use_effect_once::*;
 pub use use_event::*;
@@ -45,3 +48,4 @@ pub use use_title::*;
 pub use use_toggle::*;
 pub use use_unmount::*;
 pub use use_update::*;
+pub use use_window_size::*;
